#include <Utility.h>
#include <TDatabasePDG.h>
#include <TParticlePDG.h>

ClassImp(mciUtility);

mciUtility *mciUtility::fUtility = nullptr;
;

mciUtility::mciUtility() : Nevents(-1),
                         debug(0),
                         input_format("mcpico"),
                         output_format("mcpico")
{
}

mciUtility::~mciUtility()
{
}

mciUtility *mciUtility::GetInstance()
{
  if (fUtility == nullptr)
  {
    fUtility = new mciUtility();
  }
  return fUtility;
}

Bool_t mciUtility::ReadConfig(const TString &configFileName)
{
  if (configFileName.Length() == 0)
  {
    return false;
  }

  TEnv env(configFileName);

  Nevents = env.GetValue("Nevents", 0);
  debug = env.GetValue("debug", 0);

  return true;
}

TChain *mciUtility::initChain(const TString &inputFileName, const char *chainName)
{
  TChain *chain = new TChain(chainName);
  std::ifstream file(inputFileName.Data());
  std::string line;
  std::string basename = inputFileName.Data();
  if (basename.find(".root") != std::string::npos)
  {
    chain->Add(inputFileName.Data());
  }
  if (file.is_open())
  {
    while (std::getline(file, line))
    {
      if (line.find(".root") != std::string::npos)
      {
        chain->Add(line.c_str());
      }
    }
  }

  return chain;
}

std::vector<Float_t> mciUtility::ParseVector(std::string _input)
{
  std::vector<Float_t> vB;

  std::istringstream iss(_input);

  std::copy(std::istream_iterator<Float_t>(iss),
            std::istream_iterator<Float_t>(),
            std::back_inserter(vB));

  return vB;
}

Double_t mciUtility::GetCharge(Int_t pdg)
{
  auto particle = (TParticlePDG *)TDatabasePDG::Instance()->GetParticle(pdg);
  if (!particle)
    return error_code;
  return particle->Charge() / 3.;
}
